summaryrefslogtreecommitdiff
path: root/indoteknik_custom/models/purchase_order_line.py
diff options
context:
space:
mode:
authorstephanchrst <stephanchrst@gmail.com>2022-09-26 18:25:41 +0700
committerstephanchrst <stephanchrst@gmail.com>2022-09-26 18:25:41 +0700
commit7ae5b8b7baafb9ed302c3c3e54f3f44664651c06 (patch)
tree930ec4518e3e36f9e0a6bc980a931c1f4ed37120 /indoteknik_custom/models/purchase_order_line.py
parent98d8bb612184f5354c076f52143afcfad4e05e6f (diff)
Update purchase_order.py, purchase_order_line.py, and 2 more files...
Diffstat (limited to 'indoteknik_custom/models/purchase_order_line.py')
-rwxr-xr-xindoteknik_custom/models/purchase_order_line.py68
1 files changed, 36 insertions, 32 deletions
diff --git a/indoteknik_custom/models/purchase_order_line.py b/indoteknik_custom/models/purchase_order_line.py
index 55381c6d..4229fcea 100755
--- a/indoteknik_custom/models/purchase_order_line.py
+++ b/indoteknik_custom/models/purchase_order_line.py
@@ -1,18 +1,10 @@
-from odoo import fields, models, api
+from odoo import fields, models, api, _
+from odoo.exceptions import AccessError, UserError, ValidationError
from odoo.tools import DEFAULT_SERVER_DATETIME_FORMAT
class PurchaseOrderLine(models.Model):
_inherit = 'purchase.order.line'
- sales_price = fields.Float(
- 'Sales Price', compute='compute_item_margin',
- help="Sales Price in Purchase Order Line")
- item_margin = fields.Float(
- 'Total Margin', compute='compute_item_margin',
- help="Total Margin in Purchase Order Line")
- item_percent_margin = fields.Float(
- 'Total Percent Margin', compute='compute_item_margin',
- help="Total % Margin in Purchase Order Line")
# Override method from addons/purchase/models/purchase.py
@api.onchange('product_qty', 'product_uom')
@@ -35,25 +27,37 @@ class PurchaseOrderLine(models.Model):
self.price_unit = price_unit
return res
- def compute_item_margin(self):
- for line in self:
- if not line.product_id or line.price_unit <= 0 or line.product_uom_qty <= 0 or line.product_id.type == 'service' or not line.order_id.sale_order_id.id:
- line.item_margin = 0
- line.item_percent_margin = 0
- continue
- sale_order_line = self.env['sale.order.line'].search(
- [('product_id', '=', line.product_id.id),
- ('order_id', '=', line.order_id.sale_order_id.id)], limit=1, order='price_reduce_taxexcl')
-
- # untaxed sales price
- sales_price = sale_order_line.price_reduce_taxexcl * sale_order_line.product_uom_qty
- # must add expedition price in sales_price, expedition payed by customer?
- # sales_price -= round((line.order_id.sale_order_id.delivery_amount / line.order_id.sale_order_id.count_line_product), 2)
- # untaxed purchase price
- purchase_price = line.price_subtotal
- # must add expedition price in purchase_price as expenses
- purchase_price += round((line.order_id.delivery_amount / line.order_id.count_line_product), 2)
- margin_per_item = sales_price - purchase_price
- line.item_margin = margin_per_item
- if sales_price > 0:
- line.item_percent_margin = round((margin_per_item / sales_price), 2) * 100 \ No newline at end of file
+ # def compute_item_margin(self):
+ # for line in self:
+ # if not line.product_id or line.price_unit <= 0 or line.product_uom_qty <= 0 or line.product_id.type == 'service' or not line.order_id.sale_order_id.id:
+ # line.item_margin = 0
+ # line.item_percent_margin = 0
+ # continue
+ # sale_order_line = self.env['sale.order.line'].search(
+ # [('product_id', '=', line.product_id.id),
+ # ('order_id', '=', line.order_id.sale_order_id.id)], limit=1, order='price_reduce_taxexcl')
+ #
+ # est_purchase_price = sale_order_line.purchase_price
+ # real_purchase_price = line.price_unit
+ # real_tax = 0
+ # real_tax_amount = 0
+ # count_real_tax = 0
+ # for tax in line.taxes_id:
+ # count_real_tax += 1
+ # real_tax = tax
+ # real_tax_amount += tax.amount
+ # if sale_order_line.purchase_tax_id.amount != real_tax_amount or count_real_tax > 1:
+ # raise UserError("Beda tax amount dengan Sales")
+ #
+ # # untaxed sales price
+ # sales_price = sale_order_line.price_reduce_taxexcl * sale_order_line.product_uom_qty
+ # # must add expedition price in sales_price, expedition payed by customer?
+ # # sales_price -= round((line.order_id.sale_order_id.delivery_amount / line.order_id.sale_order_id.count_line_product), 2)
+ # # untaxed purchase price
+ # purchase_price = line.price_subtotal
+ # # must add expedition price in purchase_price as expenses
+ # purchase_price += round((line.order_id.delivery_amount / line.order_id.count_line_product), 2)
+ # margin_per_item = sales_price - purchase_price
+ # line.item_margin = margin_per_item
+ # if sales_price > 0:
+ # line.item_percent_margin = round((margin_per_item / sales_price), 2) * 100 \ No newline at end of file